@@ -9,10 +9,14 @@ from codecs import encode
 import numpy as np
 import argparse
 import joblib
-from maintain_PlatoUtils.maintain_PlatoUtils import existTag,wrapNebula2Df,existEdge,delEdge,delVertex
+# from maintain_PlatoUtils.maintain_PlatoUtils import existTag,wrapNebula2Df,existEdge,delEdge,delVertex
+from maintain_PlatoUtils import existTag,wrapNebula2Df,existEdge,delEdge,delVertex
 import joblib
 import sys
 import os.path as osp
+from nebula.graph import ttypes,GraphService
+from nebula.ConnectionPool import ConnectionPool
+from nebula.Client import GraphClient
 
 csv2platoDTypeDict={
     "object":"string",
@@ -113,7 +117,7 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
     
     for vertexI,_ in tqdm.tqdm(enumerate(rawSchemaJson["vertex"]),desc="vertex"):
         rawSchemaJson["vertex"][vertexI]["file_path"]=csvFolder+"/"+rawSchemaJson["vertex"][vertexI]["file_name"]
-        csvDfItem=pd.read_csv(rawSchemaJson["vertex"][vertexI]["file_path"])
+        csvDfItem=pd.read_csv(rawSchemaJson["vertex"][vertexI]["file_path"]).drop_duplicates()
         csvDfItem[rawSchemaJson["vertex"][vertexI]["id_col"]]=csvDfItem[rawSchemaJson["vertex"][vertexI]["id_col"]].astype(str)
         vertexType=rawSchemaJson["vertex"][vertexI]["node_type"]
         csvDfItem["newMadeSysID"]=vertexType+"_"+csvDfItem[rawSchemaJson["vertex"][vertexI]["id_col"]].astype(str)
@@ -122,6 +126,9 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
         vertexDataProcess=coverLabel.split(",")[0]
         vertexAttrProcess=coverLabel.split(",")[1]
 
+        attrTypeDf=wrapNebula2Df(gClient.execute_query("DESCRIBE TAG {}".format(vertexType)))
+        attrTypeDict=dict(attrTypeDf.values.tolist())
+
         # 节点数据控制
         if vertexDataProcess=="cover":
             nodeType=rawSchemaJson["vertex"][vertexI]["node_type"]
@@ -141,15 +148,17 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
             nodeType=rawSchemaJson["vertex"][vertexI]["node_type"]
             nodeIdAttr=rawSchemaJson["vertex"][vertexI]["id_col"]
             csvDfItem=csvDfItem.loc[csvDfItem[nodeIdAttr].map(lambda nodeAttrVal:existTag(nodeType, nodeIdAttr, nodeAttrVal,gClient)==False)]
+            
         elif vertexAttrProcess=="plus":
             
             nodeItemCInfoDf=csvDfItem.copy(deep=True)
             
             nodeType=rawSchemaJson["vertex"][vertexI]["node_type"]
             nodeIdAttr=rawSchemaJson["vertex"][vertexI]["id_col"]
-            nodeIdList=nodeItemCInfoDf[rawSchemaJson["vertex"][vertexI]["id_col"]].values.flatten().tolist()
+            nodeGIdAttr="{}.{}".format(nodeType,rawSchemaJson["vertex"][vertexI]["csv2plato_attr_map"][nodeIdAttr])
+            nodeIdList=nodeItemCInfoDf[nodeIdAttr].values.flatten().tolist()
             
-            searchBatch=32
+            searchBatch=1
             nodeItemGInfoDfList=[]
             for nodeIdI in range(0,len(nodeIdList),searchBatch):
                 queryStrList=[]
@@ -160,29 +169,40 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
                     queryStrList.append(queryStrItem)
                 queryStr=" UNION ".join(queryStrList)
                 nodeItemGInfoDf=wrapNebula2Df(gClient.execute_query(queryStr))
-                nodeItemGInfoDfList.append(nodeItemGInfoDf)
-            nodeItemGInfoDf=pd.concat(nodeItemGInfoDfList)
+                if nodeItemGInfoDf.shape[0]>0:
+                    nodeItemGInfoDfList.append(nodeItemGInfoDf)
+            nodeItemGInfoDf=pd.concat(nodeItemGInfoDfList).reset_index(drop=True)
+            nodeItemGInfoDf.drop("VertexID",axis=1,inplace=True)
             
             # print("nodeItemCInfoDf:",nodeItemCInfoDf.columns)
             # print("nodeItemGInfoDf:",nodeItemGInfoDf.columns)
-            if nodeItemGInfoDf.shape[0]>0:
-                for colItem in nodeItemCInfoDf.columns:
-                    if colItem in nodeItemGInfoDf:
-                        idAttrKey=rawSchemaJson["vertex"][vertexI]["id_col"]
-                        if colItem !=  idAttrKey:
-                            changedIdList=nodeItemCInfoDf.loc[(nodeItemCInfoDf[colItem].isna())|
-                                                            (nodeItemCInfoDf[colItem]=="null")|
-                                                            (nodeItemCInfoDf[colItem]==""),idAttrKey].values.flatten().tolist()
-
-                            cIdDf=nodeItemCInfoDf.loc[nodeItemCInfoDf[idAttrKey].isin(changedIdList),idAttrKey]
-                            gIdDf=nodeItemGInfoDf.loc[nodeItemGInfoDf[idAttrKey].isin(changedIdList),idAttrKey]
-                            
-                            # print(nodeItemCInfoDf.loc[nodeItemCInfoDf[idAttrKey].isin(gIdDf),:])
-                            # print(nodeItemGInfoDf.loc[nodeItemGInfoDf[idAttrKey].isin(gIdDf),:])
-
-                            nodeItemCInfoDf.loc[nodeItemCInfoDf[idAttrKey].isin(gIdDf),colItem]=\
-                                nodeItemGInfoDf.loc[nodeItemGInfoDf[idAttrKey].isin(gIdDf),colItem].values
+            csv2platoAttrDict=rawSchemaJson["vertex"][vertexI]["csv2plato_attr_map"]
+            plato2csvAttrDict=dict(zip(["{}.{}".format(nodeType,csv2platoAttrItem) for csv2platoAttrItem in csv2platoAttrDict.values()],
+                                       csv2platoAttrDict.keys()))
             
+            nodeItemCInfoDf=pd.merge(nodeItemCInfoDf,nodeItemGInfoDf,left_on=nodeIdAttr,right_on=nodeGIdAttr,how="left")
+            
+            for colItem in nodeItemGInfoDf:
+                if "." in colItem:
+                    mkupColName=colItem.split(".")[1]
+                    if mkupColName in nodeItemCInfoDf:
+                        mkupIndex=nodeItemCInfoDf.loc[(nodeItemCInfoDf[mkupColName].isna())|
+                                                        (nodeItemCInfoDf[mkupColName]=="")|
+                                                        (nodeItemCInfoDf[mkupColName]=="null"),:].index
+                        mkupIndex=list(mkupIndex)
+                        if len(mkupIndex)>0:
+                            mkupColIndex=list(nodeItemCInfoDf.columns).index(mkupColName)
+                            colIndex=list(nodeItemCInfoDf.columns).index(colItem)
+                            nodeItemCInfoDf.iloc[mkupIndex,mkupColIndex]=nodeItemCInfoDf.iloc[mkupIndex,colIndex]
+                    else:
+                        nodeItemCInfoDf[mkupColName]=nodeItemCInfoDf[colItem]
+                        
+                    csvPlatoAttrSetList=list(set(list(rawSchemaJson["vertex"][vertexI]["csv2plato_attr_map"].keys())+list(rawSchemaJson["vertex"][vertexI]["csv2plato_attr_map"].values())))
+                    if mkupColName not in csvPlatoAttrSetList:
+                        rawSchemaJson["vertex"][vertexI]["csv2plato_attr_map"][mkupColName]=mkupColName
+                        rawSchemaJson["vertex"][vertexI]["attr_type_map"][mkupColName]=attrTypeDict[mkupColName]
+                        
+                    nodeItemCInfoDf.drop(colItem,axis=1,inplace=True)
             csvDfItem=nodeItemCInfoDf
         elif vertexAttrProcess=="cover":
             pass
@@ -201,7 +221,7 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
 
     for edgeI,_ in tqdm.tqdm(enumerate(rawSchemaJson["edge"]),desc="edge"):
         rawSchemaJson["edge"][edgeI]["file_path"]=csvFolder+"/"+rawSchemaJson["edge"][edgeI]["file_name"]
-        csvDfItem=pd.read_csv(rawSchemaJson["edge"][edgeI]["file_path"])
+        csvDfItem=pd.read_csv(rawSchemaJson["edge"][edgeI]["file_path"]).drop_duplicates()
         srcType=rawSchemaJson["edge"][edgeI]["src_type"]
         tgtType=rawSchemaJson["edge"][edgeI]["tgt_type"]
         edgeType=rawSchemaJson["edge"][edgeI]["edge_type"]
@@ -413,7 +433,19 @@ if __name__=="__main__":
     platoUrl="http://9.135.95.249:7001"
     # platoUrl="http://10.99.218.40:8081"
     
-    uploadFolder(dataFolder,platoUrl)
+    gdbHost="9.135.95.249"
+    gdbPort=13708
+    gdbUser="root"
+    gdbPassword="nebula"
+    
+    connection_pool = ConnectionPool(gdbHost,gdbPort,network_timeout=60000)
+    gClient = GraphClient(connection_pool)
+    gClient.authenticate(gdbUser, gdbPassword)
+    gClient.execute_query("USE post_skill_school_ianxu")
+    
+    with open("./YunPostSkill/rawSchema.json","r") as rawSchemaJsonFile:
+        rawSchemaJson=json.load(rawSchemaJsonFile)
+    remakeRawSchema(rawSchemaJson,"YunPostSkill",gClient)
     
     print("finished")
                 
