@@ -6,6 +6,7 @@ import pandas as pd
 import json
 import os
 import requests
+import numpy as np
 
 def buildVertex(vertexJson,graphClient,nodeSysIDUUID=True):
 
@@ -48,6 +49,9 @@ def buildVertex(vertexJson,graphClient,nodeSysIDUUID=True):
                                     "type": csv_attr2type_map[attrKeyItem],
                                     "index": list(vertexDf.columns).index(attrKeyItem)
                                 })
+                        elif csv_attr2type_map[attrKeyItem]=="int" and vertexDf[attrKeyItem].dtype==np.float64:
+                            vertexDf[attrKeyItem].fillna(0,inplace=True)
+                            vertexDf[attrKeyItem]=vertexDf[attrKeyItem].astype(int)
                         else:
                             raise TypeError("csv({}_{})与uploadSchema.json类型冲突，请核查".format(vertexPath.split("/")[-1],
                                                                                             attrKeyItem))
@@ -155,7 +159,9 @@ def createSchemaFromSchemaJson(schemaJson,graphClient):
     rebuildTagIndexErrCode=0
     createEdgeErrCode=0
     schemaJson["vertex"]=schemaJson.get("vertex",[])+[{"node_type":"Alias","old_id_col":"Name","attr_type_map":{"Name":"string"}}]
+    schemaJson["vertex"].pop(-1)
     schemaJson["edge"]=schemaJson.get("edge",[])+[{"edge_type":"aliasNameOf","attr_type_map":{}}]
+    schemaJson["edge"].pop(-1)
     if "vertex" in schemaJson: # 构建节点schema
         schemaTagList=schemaJson["vertex"]
         for schemaTagItem in schemaTagList:
